@@ -90,16 +90,16 @@ async def test_module_method():
 
     with lupy.record(
         targets={
-            'tests.fixtures.module_level_function': None
+            'tests.fixtures.module_level_function': ['p']
         },
         recordings_dir='tests/fixtures/recordings/',
     ):
         # First call: executes original function and writes recording
-        r1 = fixtures.module_level_function()
+        r1 = fixtures.module_level_function({'a': 1})
         assert r1 is True
         assert fixtures.module_counter == 1
 
         # Second call: reads from recording; call_count should not increase
-        r2 = fixtures.module_level_function()
+        r2 = fixtures.module_level_function({'a': 1})
         assert r2 is True
         assert fixtures.module_counter == 1
